TransportResponse

Struct TransportResponse 

pub struct TransportResponse {
    pub status: u16,
    pub url: Url,
    pub headers: Vec<(String, String)>,
    pub body: BodyStream,
}
A response produced by an HttpTransport.

The body is a streaming byte source so fetchkit can apply its body-size cap, body timeout, and partial-content-on-timeout logic while reading.

Fields

status: u16

HTTP status code.

url: Url

Final URL after the transport executed the request (same as request URL; fetchkit follows redirects itself, so this normally equals the request URL).

headers: Vec<(String, String)>

Response headers.

body: BodyStream

Streaming response body.